@@ -15,6 +15,11 @@ charpick_data curr_data;
  */
 
 /* The comment for each char list has the html entity names of the chars */
+
+/* This is the default list used when starting charpick the first time */
+/* aacute, agrave, eacute, iacute, oacute, frac12, copy*/
+static const gchar *def_list = "";
+
 /* aacute, agrave, acirc, atilde, auml. aring, aelig, ordf */
 static const gchar *a_list = "";
 static const gchar *cap_a_list = "ƪ";
@@ -454,6 +459,16 @@ about (AppletWidget *applet, gpointer data)
   data = NULL;
 }
 
+
+static void
+help_cb (GtkWidget *w, gpointer data)
+{
+        GnomeHelpMenuEntry help_entry = { "charpick_applet",
+                                          "index.html" };
+        gnome_help_display(NULL, &help_entry);
+}
+
+
 int
 main (int argc, char *argv[])
 {
@@ -469,7 +484,7 @@ main (int argc, char *argv[])
 
   charpick_persistant_properties default_properties = 
   {
-    NULL, /* a_list */
+    NULL, /* will use def_list */
     TRUE,
     8,
     2,
@@ -492,7 +507,7 @@ main (int argc, char *argv[])
   };
   */
 
-  default_properties.default_charlist = a_list;
+  default_properties.default_charlist = def_list;
   curr_data.charlist = default_properties.default_charlist;
   curr_data.selected_char = ' ';
   curr_data.last_index = NO_LAST_INDEX;
@@ -566,13 +581,6 @@ main (int argc, char *argv[])
   gtk_signal_connect(GTK_OBJECT(applet),"change_orient",
 		     GTK_SIGNAL_FUNC(applet_change_orient), NULL);
 
-  applet_widget_register_stock_callback (APPLET_WIDGET (applet),
-				         "about",
-					 GNOME_STOCK_MENU_ABOUT,
-					 _("About..."),
-					 about,
-					 NULL);
-
   applet_widget_register_stock_callback (APPLET_WIDGET (applet),
 				         "properties",
 					 GNOME_STOCK_MENU_PROP,
@@ -580,6 +588,19 @@ main (int argc, char *argv[])
 					 property_show,
 					 &curr_data);
 
+  applet_widget_register_stock_callback (APPLET_WIDGET (applet),
+				         "help",
+					 GNOME_STOCK_PIXMAP_HELP,
+					 _("Help"),
+					 help_cb, NULL);
+
+  applet_widget_register_stock_callback (APPLET_WIDGET (applet),
+				         "about",
+					 GNOME_STOCK_MENU_ABOUT,
+					 _("About..."),
+					 about,
+					 NULL);
+
 
   
   applet_widget_add (APPLET_WIDGET (applet), frame);
