@@ -272,8 +272,14 @@ static void
 about (AppletWidget *applet, gpointer data)
 {
 	static const char *authors[] = { "Federico Mena", NULL };
-	GtkWidget *about_box;
+	static GtkWidget *about_box = NULL;
 
+	if (about_box != NULL)
+	{
+		gdk_window_show(about_box->window);
+		gdk_window_raise(about_box->window);
+		return;
+	}
 	about_box = gnome_about_new (_("Fifteen sliding pieces"),
 				     VERSION,
 				     _("Copyright (C) The Free Software Foundation"),
@@ -282,6 +288,8 @@ about (AppletWidget *applet, gpointer data)
 				       "now for your delight in the Gnome Panel. "
 				       "Guaranteed to be a productivity buster."),
 				     NULL);
+	gtk_signal_connect( GTK_OBJECT(about_box), "destroy",
+			    GTK_SIGNAL_FUNC(gtk_widget_destroyed), &about_box );
 
 	gtk_widget_show(about_box);
 	return;
@@ -305,6 +313,13 @@ change_pixel_size(GtkWidget *w, int size, gpointer data)
 	w = NULL;
 }
 
+static void
+help_cb (AppletWidget *applet, gpointer data)
+{
+    GnomeHelpMenuEntry help_entry = { "fifteen_applet", "index.html"};
+    gnome_help_display(NULL, &help_entry);
+}
+
 int
 main (int argc, char **argv)
 {
@@ -340,6 +355,11 @@ main (int argc, char **argv)
 					 scramble,
 					 fifteen);
 
+	applet_widget_register_stock_callback (APPLET_WIDGET (applet),
+					       "help",
+					       GNOME_STOCK_PIXMAP_HELP,
+					       _("Help"), help_cb, NULL);
+
 	applet_widget_register_stock_callback (APPLET_WIDGET (applet),
 					       "about",
 					       GNOME_STOCK_MENU_ABOUT,
