@@ -1,4 +1,4 @@
-/* $Id: gweather-applet.c,v 1.18 2000/03/16 16:50:11 jberkman Exp $ */
+/* $Id: gweather-applet.c,v 1.20 2000/04/18 04:38:20 dmueth Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -147,9 +147,8 @@ static void about_cb (AppletWidget *widget, gpointer data)
 
 static void help_cb (AppletWidget *applet, gpointer data)
 {
-    static GnomeHelpMenuEntry help_entry = { NULL, "index.html"};
+    static GnomeHelpMenuEntry help_entry = { "gweather_applet", "index.html"};
 
-    help_entry.name = gnome_app_id;
     gnome_help_display(NULL, &help_entry);
 }
 
