@@ -1,4 +1,4 @@
-/* $Id: jbc-applet.c,v 1.12 2000/01/29 01:07:27 jirka Exp $
+/* $Id: jbc-applet.c,v 1.14 2000/02/29 21:13:15 jberkman Exp $
  *
  * Jon's Binary Clock, GNOMEified
  *
@@ -38,10 +38,16 @@ static gboolean panel_vertical = FALSE;
 static gint
 about_jbc ()
 {
-  GtkWidget *about;
+  static GtkWidget *about = NULL;
   const gchar *authors[2];
   /* gchar version[32]; */
 
+  if (about != NULL)
+  {
+  	gdk_window_show(about->window);
+	gdk_window_raise(about->window);
+	return TRUE;
+  }
   authors[0] = "Jon Anhold <jon@snoopy.net>";
   authors[1] = NULL;
 
@@ -53,6 +59,8 @@ about_jbc ()
 			  "Displays time in Binary Coded Decimal\n"
 			  "http://snoopy.net/~jon/jbc/."),
 			   NULL);
+  gtk_signal_connect( GTK_OBJECT(about), "destroy",
+		      GTK_SIGNAL_FUNC(gtk_widget_destroyed), &about );
   gtk_widget_show (about);
 
   return TRUE;
@@ -140,6 +148,14 @@ change_orient (GtkWidget *applet, PanelOrientType o, GtkWidget *canvas)
 	redo_size (canvas);
 }
 
+static void
+help_cb (AppletWidget *applet, gpointer data)
+{
+    GnomeHelpMenuEntry help_entry = { "jbc_applet", "index.html"};
+    gnome_help_display(NULL, &help_entry);
+}
+
+
 int
 main (int argc, char **argv)
 {
@@ -174,6 +190,11 @@ main (int argc, char **argv)
 
   gtk_widget_show (applet);
 
+  applet_widget_register_stock_callback (APPLET_WIDGET (applet),
+					 "help",
+					 GNOME_STOCK_PIXMAP_HELP,
+					 _("Help"), help_cb, NULL);
+
   applet_widget_register_stock_callback (APPLET_WIDGET (applet),
 					 "about",
 					 GNOME_STOCK_MENU_ABOUT,
