@@ -75,7 +75,7 @@ make_swapload_applet (const gchar *goad_id)
 			&multiload_properties.swapload, prop_data,
 			multiload_properties.swapload.adj_data[0],
 			multiload_properties.swapload.adj_data[1], GetSwap,
-			"swapload-applet.html#SWAPLOAD-PROPERTIES");
+			"index.html#SWAPLOAD-PROPERTIES");
 
     applet_widget_add (APPLET_WIDGET(applet), g->main_widget);
     gtk_widget_show (applet);
@@ -107,7 +107,7 @@ make_swapload_applet (const gchar *goad_id)
 					   GNOME_STOCK_PIXMAP_HELP,
 					   _("Help"),
 					   multiload_help_cb,
-					   "swapload-applet.html");
+					   "swapload_applet");
 
     applet_widget_register_stock_callback (APPLET_WIDGET(applet),
 					   "about",
